import request from '@/utils/request'

// 查询证书列表
export function listDept(query) {
  return request({
    url: '/mall-certificat/list',
    method: 'get',
    params: query
  })
}

// 查询证书列表（排除节点）
export function listDeptExcludeChild(query) {
  return request({
    url: '/mall-certificat/list/excludeChild',
    method: 'get',
    params: query
  })
}

// 查询证书详细
export function getDept(query) {
  return request({
    url: '/mall-certificat/getInfo',
    method: 'get',
    params: query
  })
}

// 新增证书
export function addDept(data) {
  return request({
    url: '/mall-certificat/add',
    method: 'post',
    data: data
  })
}

// 修改证书
export function updateDept(data) {
  return request({
    url: '/mall-certificat/edit',
    method: 'post',
    data: data
  })
}

// 删除证书
export function delDept(query) {
  return request({
    url: '/mall-certificat/remove',
    method: 'post',
    params: query
  })
}

export function list(query) {
  return request({
    url: '/mall-integral-obtain/certificate/sys/page',
    method: 'get',
    params:query
  })
}

export function complete(query) {
  return request({
    url: '/mall-integral-obtain/certificate/complete',
    method: 'post',
    params:query
  })
}

export function types(query) {
  return request({
    url: '/mall-integral-obtain/certificate/types',
    method: 'get',
    params:query
  })
}




